# Generated by Django 2.2.9 on 2020-01-30 14:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0006_auto_20200129_2252"),
    ]

    operations = [
        migrations.RemoveField(model_name="playlistentry", name="song",),
    ]
